#ifndef __VID_MAIN_H__
#define __VID_MAIN_H__
//****************************************************************************
//**
//**    VID_MAIN.H
//**    Header - Video Interface
//**
//**    Copyright (c) 1998 Chris Hargrove
//**    Notice: Usage of any code in this file is subject to the rules
//**            described in the LICENSE.TXT file included in this directory.
//**            Reading, compiling, or otherwise using this code constitutes
//**            automatic acceptance of the rules in said text file.
//**
//****************************************************************************
//============================================================================
//    INTERFACE REQUIRED HEADERS
//============================================================================
#include "sys_defs.h"
//============================================================================
//    INTERFACE DEFINITIONS / ENUMERATIONS / SIMPLE TYPEDEFS
//============================================================================
typedef void* vid_modeinfo_t;

//============================================================================
//    INTERFACE CLASS PROTOTYPES / EXTERNAL CLASS REFERENCES
//============================================================================
//============================================================================
//    INTERFACE STRUCTURES / UTILITY CLASSES
//============================================================================
//============================================================================
//    INTERFACE DATA DECLARATIONS
//============================================================================
//============================================================================
//    INTERFACE FUNCTION PROTOTYPES
//============================================================================

// init/shutdown/frame
void VID_Init();
void VID_Shutdown();
void VID_Frame();

// image control
res_id_t VID_RegisterImage(char* fileName, bbool masking);

dword VID_LoadImage(byte* imageData, sdword width, sdword height, dword bitDepth, bbool masking);
void VID_FreeImage(dword imageHandle);
void VID_DrawImage(dword imageHandle, sdword scrX, sdword scrY);
byte* VID_LockImage(dword imageHandle, dword* outImgPitch);
void VID_UnlockImage(dword imageHandle, byte* lockPtr);
dword VID_GetImageWidth(dword imageHandle);
dword VID_GetImageHeight(dword imageHandle);
dword VID_GetImageBitDepth(dword imageHandle);

// video mode control
bbool VID_SetMode(void* mode);
bbool VID_SetModeEx(dword width, dword height, dword bitDepth);
dword VID_GetAvailableModes(void** modeList, dword maxModes);
dword VID_GetModeWidth(void* mode);
dword VID_GetModeHeight(void* mode);
dword VID_GetModeBitDepth(void* mode);
char* VID_GetModeDeviceName(void* mode);
char* VID_GetModeDeviceDescription(void* mode);

// palette control
void VID_SetPaletteRange(byte* buffer, dword startColor, dword numColors);
void VID_SetPaletteEntry(byte color, byte r, byte g, byte b);
void VID_GetPaletteEntry(byte color, byte *r, byte *g, byte *b);

//============================================================================
//    INTERFACE OBJECT CLASS DEFINITIONS
//============================================================================
//============================================================================
//    INTERFACE TRAILING HEADERS
//============================================================================

//****************************************************************************
//**
//**    END HEADER VID_MAIN.H
//**
//****************************************************************************
#endif // __VID_MAIN_H__
